@@ -3,15 +3,16 @@ Main interface for accessanalyzer service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.accessanalyzer import (
+    from mypy_boto3_accessanalyzer import (
         AccessAnalyzerClient,
         Client,
         ListAnalyzedResourcesPaginator,
         ListAnalyzersPaginator,
         ListArchiveRulesPaginator,
         ListFindingsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -22,6 +23,7 @@ Usage::
     list_analyzers_paginator: ListAnalyzersPaginator = client.get_paginator("list_analyzers")
     list_archive_rules_paginator: ListArchiveRulesPaginator = client.get_paginator("list_archive_rules")
     list_findings_paginator: ListFindingsPaginator = client.get_paginator("list_findings")
+    ```
 """
 from mypy_boto3_accessanalyzer.client import AccessAnalyzerClient, AccessAnalyzerClient as Client
 from mypy_boto3_accessanalyzer.paginator import (
