@@ -3,8 +3,11 @@ Main interface for accessanalyzer service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.accessanalyzer import (
+
+    from mypy_boto3_accessanalyzer import AccessAnalyzerClient
+    from mypy_boto3_accessanalyzer import (
         ListAnalyzedResourcesPaginator,
         ListAnalyzersPaginator,
         ListArchiveRulesPaginator,
@@ -17,6 +20,7 @@ Usage::
     list_analyzers_paginator: ListAnalyzersPaginator = client.get_paginator("list_analyzers")
     list_archive_rules_paginator: ListArchiveRulesPaginator = client.get_paginator("list_archive_rules")
     list_findings_paginator: ListFindingsPaginator = client.get_paginator("list_findings")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
@@ -48,7 +52,7 @@ __all__ = (
 
 class ListAnalyzedResourcesPaginator(Boto3Paginator):
     """
-    [Paginator.ListAnalyzedResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
+    [Paginator.ListAnalyzedResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
     """
 
     def paginate(
@@ -65,13 +69,13 @@ class ListAnalyzedResourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAnalyzedResourcesResponseTypeDef]:
         """
-        [ListAnalyzedResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
+        [ListAnalyzedResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
         """
 
 
 class ListAnalyzersPaginator(Boto3Paginator):
     """
-    [Paginator.ListAnalyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
+    [Paginator.ListAnalyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
     """
 
     def paginate(
@@ -80,26 +84,26 @@ class ListAnalyzersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAnalyzersResponseTypeDef]:
         """
-        [ListAnalyzers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
+        [ListAnalyzers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
         """
 
 
 class ListArchiveRulesPaginator(Boto3Paginator):
     """
-    [Paginator.ListArchiveRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
+    [Paginator.ListArchiveRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
     """
 
     def paginate(
         self, analyzerName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListArchiveRulesResponseTypeDef]:
         """
-        [ListArchiveRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
+        [ListArchiveRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
         """
 
 
 class ListFindingsPaginator(Boto3Paginator):
     """
-    [Paginator.ListFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+    [Paginator.ListFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
     """
 
     def paginate(
@@ -110,5 +114,5 @@ class ListFindingsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListFindingsResponseTypeDef]:
         """
-        [ListFindings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
+        [ListFindings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
         """
